@@ -17,7 +17,7 @@ class Session(object):
 
         self._url = config.CACHE_URL
         url_protocol = str(self._url).lower().split(":")
-        self._protocol = url_protocol
+        self._protocol = url_protocol[0]
 
         switch = {
             "redis": SessionFactory.create_redis,
